SearchError

Enum SearchError 

#[non_exhaustive]
pub enum SearchError {
Show 16 variants InvalidConfig(&'static str), DimensionMismatch { expected: usize, actual: usize, vector: Option<usize>, }, NonFiniteValue { vector: Option<usize>, dimension: usize, }, ZeroVector { vector: Option<usize>, }, DuplicateKey(u64), DuplicateVectorId { key: u64, vector_id: u64, }, CapacityOverflow, AllocationFailed, WorkerPanic, Storage { operation: &'static str, kind: ErrorKind, }, CorruptSnapshot(&'static str), UnsupportedSnapshotVersion(u32), MissingKey(u64), EmbeddingFailed(String), ShardFailed { shard: usize, message: String, }, MutationConflict,
}
Typed build and query failures.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidConfig(&'static str)

The supplied crate::IndexConfig cannot construct a valid index.



DimensionMismatch

A vector or query did not match the configured dimensionality.

Fields

expected: usize

Required number of components.

actual: usize

Observed number of components.

vector: Option<usize>

Input-vector position, or None when validating a query.



NonFiniteValue

A vector or query component was NaN or infinite.

Fields

vector: Option<usize>

Input-vector position, or None when validating a query.

dimension: usize

Position of the invalid component.



ZeroVector

A stored vector or query had zero magnitude.

Fields

vector: Option<usize>

Input-vector position, or None when validating a query.



DuplicateKey(u64)

More than one stored vector used the same caller-provided key.



DuplicateVectorId

More than one vector used the same key and per-key vector identifier.

Fields

key: u64
vector_id: u64


CapacityOverflow

Index sizes or degree arithmetic exceeded supported capacity.



AllocationFailed

A fallible reservation for index or query storage failed.



WorkerPanic

A bounded build or query worker panicked.



Storage

A filesystem operation failed while reading or writing an index.

Fields

operation: &'static str

Operation that failed.

kind: ErrorKind

Portable operating-system error category.



CorruptSnapshot(&'static str)

A persisted index failed structural or integrity validation.



UnsupportedSnapshotVersion(u32)

The snapshot format is newer or older than this crate understands.



MissingKey(u64)

A requested vector key was not present.



EmbeddingFailed(String)

An embedding provider rejected an input or failed to produce a vector.



ShardFailed

A local or remote search shard failed.

Fields

shard: usize

Stable zero-based shard position.

message: String

Provider-specific failure text.



MutationConflict

Mutations changed while an optimistic compaction was being built.