SnapshotValidation

Enum SnapshotValidation 

pub enum SnapshotValidation {
    Full,
    StructureOnly,
}
Integrity policy used while opening a memory-mapped snapshot.

Variants



Full

Validate structure, finite vectors, and the full payload checksum.



StructureOnly

Validate all ranges and graph references without scanning the checksum.